**Example 1: 刷新接入配置检查结果**



Input: 

```
tccli waf RefreshAccessCheckResult --cli-unfold-argument  \
    --Domain www.test.com
```

Output: 
```
{
    "Response": {
        "RequestId": "9ee8be5b-6caa-4c39-ab70-890e0e673515"
    }
}
```

